.. _output:

Output
========

Print to screen
-----------------------------------

.. automodule:: tabledataextractor.output.print
    :members:


Save to file
----------------------------------

.. automodule:: tabledataextractor.output.to_csv
    :members:


Convert to Pandas DataFrame
------------------------------------

.. automodule:: tabledataextractor.output.to_pandas
    :members:



